@@ -1,5 +1,5 @@
 # SystemC - SystemC Perl Interface
-# $Id: Module.pm,v 1.41 2002/03/11 15:52:09 wsnyder Exp $
+# $Revision: #44 $$Date: 2002/08/07 $$Author: wsnyder $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
@@ -7,9 +7,7 @@
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of either the GNU General Public License or the
-# Perl Artistic License, with the exception that it cannot be placed
-# on a CD-ROM or similar media for commercial distribution without the
-# prior approval of the author.
+# Perl Artistic License.
 # 
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -34,7 +32,7 @@ use SystemC::Netlist::AutoCover;
 use SystemC::Netlist::AutoTrace;
 
 @ISA = qw(Verilog::Netlist::Module);
-$VERSION = '1.100';
+$VERSION = '1.110';
 use strict;
 
 sub new_net {
@@ -166,7 +164,7 @@ sub _write_autodecls {
     if (!$self->_ctor()) {
 	$fileref->print("${prefix}SC_CTOR(",$self->name,");\n");
     }
-    if ($self->_autotrace()) {
+    if ($self->_autotrace('on')) {
 	$fileref->print
 	    ("#if WAVES\n",
 	     "${prefix}void trace (SpTraceFile *tfp, int levels, int options=0);\n",
